==> byteplus_rtc-3.51.1.tar.gz: lib/api/bytertc_ktv_player_api.dart <==
// Copyright 2022 BytePlus Pte. Ltd.
// SPDX-License-Identifier: MIT

import 'bytertc_ktv_defines.dart';

/// [musicId]: Music ID.
///
/// [progress]: Music playing progress in milliseconds.
typedef OnPlayProgressType = void Function(String musicId, int progress);

/// [musicId]: Music ID.
///
/// [playState]: Music playing status.
///
/// [error]: Music playing error code.
typedef OnPlayStateChangeType = void Function(
    String musicId, KTVPlayState playState, KTVPlayerError error);

/// KTV player event handler.
class RTCKTVPlayerEventHandler {
  /// Callback for music playing progress.
  OnPlayProgressType? onPlayProgress;

  /// Callback for music playback status change.
  ///
  /// You will receive this callback on following events:
  /// + When you successfully start playing music by calling [RTCKTVPlayer.playMusic], you will receive this callback with the playState being `playing`. Otherwise the playState will be `failed`.
  /// + If the music with the same music ID is playing when you call [RTCKTVPlayer.playMusic] again, the music will restart from the starting position, and you will receive this callback with `playing` playState to inform the latter music has started.
  /// + When you successfully pause the music by calling [RTCKTVPlayer.pauseMusic], you will receive this callback with `paused` playState. Otherwise the playState will be `failed`.
  /// + When you successfully resume the music by calling [RTCKTVPlayer.resumeMusic], you will receive this callback with `playing` playState. Otherwise the playState will be `failed`.
  /// + When you successfully stop the music by calling [RTCKTVPlayer.stopMusic], you will receive this callback with `stoped` playState. Otherwise the playState will be `failed`.
  /// + When the music ends, you will receive this callback with `finished` playState.
  OnPlayStateChangeType? onPlayStateChange;

  RTCKTVPlayerEventHandler({
    this.onPlayProgress,
    this.onPlayStateChange,
  });
}

/// KTV player API class.
abstract class RTCKTVPlayer {
  /// Sets the KTV player event handler.
  void setPlayerEventHandler(RTCKTVPlayerEventHandler? eventHandler);

  /// Plays the music.
  ///
  /// [musicId]: Music ID.<br>
  /// If the song with the same musicId is playing when you call this API, the music will restart from the starting position. <br>
  /// An error will be triggered if the audio file corresponding to musicId does not exist.
  ///
  /// [trackType]: Audio track type of the KTV player.
  ///
  /// [playType]: Audio play type.
  ///
  /// After calling this API, you can receive music playing status through [RTCKTVPlayerEventHandler.onPlayStateChange].
  Future<void> playMusic(
    String musicId, {
    required KTVAudioTrackType trackType,
    required KTVAudioPlayType playType,
  });

  /// Pauses the music playing.
  ///
  /// After calling this API, you can receive music playing status through [RTCKTVPlayerEventHandler.onPlayStateChange].
  Future<void> pauseMusic(String musicId);

  /// Resumes playing the music.
  ///
  /// After calling this API, you can receive music playing status through [RTCKTVPlayerEventHandler.onPlayStateChange].
  Future<void> resumeMusic(String musicId);

  /// Stops playing the music.
  ///
  /// After calling this API, you can receive music playing status through [RTCKTVPlayerEventHandler.onPlayStateChange].
  Future<void> stopMusic(String musicId);

  /// Sets the starting position of the music file.
  ///
  /// [musicId]: Music ID.
  ///
  /// [position]: The starting position of the music file in milliseconds. The value must be less than the total length of the music.
  ///
  /// Notes:
  /// + The music must be playing when you call this API.
  /// + After calling this API, you can receive music playing status through [RTCKTVPlayerEventHandler.onPlayStateChange].
  Future<void> seekMusic(
    String musicId, {
    required int position,
  });

  /// Sets the volume of the playing music. The music must be playing when you set the volume.
  ///
  /// [musicId]: Music ID.
  ///
  /// [volume]: Music playing volume within the range of [0,400].
  /// + 0: Mute.
  /// + 100: Original volume.
  /// + 400: 4 times the original volume (with overflow protection).
  ///
  /// Notes
  /// + The music must be playing when you call this API.
  /// + If the set volume is greater than 400, it will be adjusted by the maximum value of 400; if the set volume is less than 0, it will be adjusted by the minimum value of 0.
  /// + After calling this API, you can receive music playing status through [RTCKTVPlayerEventHandler.onPlayStateChange].
  Future<void> setMusicVolume(
    String musicId, {
    required int volume,
  });

  /// Switches the audio track type between the original track and the instrumental track.
  ///
  /// The music must be playing when you call this API.
  Future<void> switchAudioTrackType(String musicId);

  /// Transposes up/down the music being played.
  ///
  /// [musicId]: Music ID.
  ///
  /// [pitch]: The pitch up/down value relative to the original pitch, in the range of [-12, 12], with the default value of 0.
  /// The difference in pitch between two adjacent values is a semitone. A positive value indicates an increase in pitch, and a negative value indicates a decrease in pitch. A larger absolute value means more pitch increase or decrease.
  ///
  /// Notes:
  /// + The music must be playing when you call this API.
  /// + After calling this API, you can receive music playing status through [RTCKTVPlayerEventHandler.onPlayStateChange].
  Future<void> setMusicPitch(
    String musicId, {
    required int pitch,
  });
}

==> byteplus_rtc-3.56.1.tar.gz: lib/api/bytertc_ktv_player_api.dart <==
// Copyright 2023 BytePlus Pte. Ltd.
// SPDX-License-Identifier: MIT

import 'bytertc_ktv_defines.dart';

/// [musicId]: Music ID.
///
/// [progress]: Music playing progress in milliseconds.
typedef OnPlayProgressType = void Function(String musicId, int progress);

/// [musicId]: Music ID.
///
/// [playState]: Music playing status.
///
/// [errorCode]: Music playing error code.
typedef OnPlayStateChangedType = void Function(
    String musicId, PlayState playState, KTVPlayerErrorCode errorCode);

/// KTV player event handler.
class RTCKTVPlayerEventHandler {
  /// Callback for music playing progress.
  OnPlayProgressType? onPlayProgress;

  /// Callback for music playback status change.
  ///
  /// You will receive this callback on following events:
  /// + When you successfully start playing music by calling [RTCKTVPlayer.playMusic], you will receive this callback with the playState being `playing`. Otherwise the playState will be `failed`.
  /// + If the music with the same music ID is playing when you call [RTCKTVPlayer.playMusic] again, the music will restart from the starting position, and you will receive this callback with `playing` playState to inform the latter music has started.
  /// + When you successfully pause the music by calling [RTCKTVPlayer.pauseMusic], you will receive this callback with `paused` playState. Otherwise the playState will be `failed`.
  /// + When you successfully resume the music by calling [RTCKTVPlayer.resumeMusic], you will receive this callback with `playing` playState. Otherwise the playState will be `failed`.
  /// + When you successfully stop the music by calling [RTCKTVPlayer.stopMusic], you will receive this callback with `stopped` playState. Otherwise the playState will be `failed`.
  /// + When the music ends, you will receive this callback with `finished` playState.
  OnPlayStateChangedType? onPlayStateChanged;

  /// @nodoc
  RTCKTVPlayerEventHandler({
    this.onPlayProgress,
    this.onPlayStateChanged,
  });
}

/// KTV player API class.
abstract class RTCKTVPlayer {
  /// Sets the KTV player event handler.
  void setPlayerEventHandler(RTCKTVPlayerEventHandler? eventHandler);

  /// Plays the music.
  ///
  /// [musicId]: Music ID.<br>
  /// If the song with the same musicId is playing when you call this API, the music will restart from the starting position. <br>
  /// An error will be triggered if the audio file corresponding to musicId does not exist.
  ///
  /// [trackType]: Audio track type of the KTV player.
  ///
  /// [playType]: Audio play type.
  ///
  /// After calling this API, you can receive music playing status through [RTCKTVPlayerEventHandler.onPlayStateChanged].
  Future<void> playMusic(
    String musicId, {
    required AudioTrackType trackType,
    required AudioPlayType playType,
  });

  /// Pauses the music playing.
  ///
  /// After calling this API, you can receive music playing status through [RTCKTVPlayerEventHandler.onPlayStateChanged].
  Future<void> pauseMusic(String musicId);

  /// Resumes playing the music.
  ///
  /// After calling this API, you can receive music playing status through [RTCKTVPlayerEventHandler.onPlayStateChanged].
  Future<void> resumeMusic(String musicId);

  /// Stops playing the music.
  ///
  /// After calling this API, you can receive music playing status through [RTCKTVPlayerEventHandler.onPlayStateChanged].
  Future<void> stopMusic(String musicId);

  /// Sets the starting position of the music file.
  ///
  /// [musicId]: Music ID.
  ///
  /// [position]: The starting position of the music file in milliseconds. The value must be less than the total length of the music.
  ///
  /// Notes:
  /// + The music must be playing when you call this API.
  /// + After calling this API, you can receive music playing status through [RTCKTVPlayerEventHandler.onPlayStateChanged].
  Future<void> seekMusic(
    String musicId, {
    required int position,
  });

  /// Sets the volume of the playing music. The music must be playing when you set the volume.
  ///
  /// [musicId]: Music ID.
  ///
  /// [volume]: Music playing volume within the range of [0,400].
  /// + 0: Mute.
  /// + 100: Original volume.
  /// + 400: 4 times the original volume (with overflow protection).
  ///
  /// Notes
  /// + The music must be playing when you call this API.
  /// + If the set volume is greater than 400, it will be adjusted by the maximum value of 400; if the set volume is less than 0, it will be adjusted by the minimum value of 0.
  /// + After calling this API, you can receive music playing status through [RTCKTVPlayerEventHandler.onPlayStateChanged].
  Future<void> setMusicVolume(
    String musicId, {
    required int volume,
  });

  /// Switches the audio track type between the original track and the instrumental track.
  ///
  /// The music must be playing when you call this API.
  Future<void> switchAudioTrackType(String musicId);

  /// Transposes up/down the music being played.
  ///
  /// [musicId]: Music ID.
  ///
  /// [pitch]: The pitch up/down value relative to the original pitch, in the range of [-12, 12], with the default value of 0.
  /// The difference in pitch between two adjacent values is a semitone. A positive value indicates an increase in pitch, and a negative value indicates a decrease in pitch. A larger absolute value means more pitch increase or decrease.
  ///
  /// Notes:
  /// + The music must be playing when you call this API.
  /// + After calling this API, you can receive music playing status through [RTCKTVPlayerEventHandler.onPlayStateChanged].
  Future<void> setMusicPitch(
    String musicId, {
    required int pitch,
  });
}
